import { ImageBaseUrl } from "@/configs/api";
import { cn } from "@/lib/utils";
import Image from "next/image";

interface ProductImagesProps {
	images: any[];
	selectedImage: string;
	setSelectedImage: (image: string) => void;
	data: any;
}

const ProductImages = ({ images, selectedImage, setSelectedImage, data }: ProductImagesProps) => {
	return (
		<div className="flex flex-col gap-4">
			<div className="relative aspect-square h-[540px] w-[540px] overflow-hidden rounded-lg bg-gray-100"
				style={{
					boxShadow: "0px 4px 4px 0px #00000040",
				}}
			>
				<Image
					src={selectedImage ? ImageBaseUrl + selectedImage : "/default-image.png"}
					alt={data?.name_en ?? ""}
					fill
					className="object-cover"
				/>
			</div>
			<div className="flex gap-2 overflow-x-auto pb-2">
				{images?.map((image: any) => (
					<div key={image?.id} className="h-[85px] w-auto">
						<Image
							src={image?.image_path ? ImageBaseUrl + image?.image_path : "/default-image.png"}
							alt={image?.name ?? ""}
							width={100}
							height={85}
							className={cn(
								"h-full w-auto cursor-pointer object-contain rounded-lg border-2 transition-all hover:opacity-80",
								selectedImage === image?.image_path ? "border-custom-primary-accent" : "border-gray-300"
							)}
							onClick={() => setSelectedImage(image?.image_path)}
						/>
					</div>
				))}
			</div>
		</div>
	);
};

export default ProductImages; 